<?php 

/* <WP plugin data>
 * Plugin Name:   More Smilies
 * Version:       2.1
 * Plugin URI:    http://mattread.com/projects/wp-plugins/more-smilies-plugin/
 * Description:   Allows you to choose different emoticon (smiley) sets to use in WP.
 * Author:        Matt Read
 * Author URI:    http://www.mattread.com/
 *
 * License:       GNU General Public License
 *
 * 
 * Copyright (C) 2005  Matt Read
 * 
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 * 
 * You can contact the author by any of the following ways:
 * 
 * Paper Mail:
 *  Matt Read
 *  102 Delaney Drive
 *  Ottawa, ON K0A 1L0 CA
 * 
 * Email:
 *  mattread@mattread.com
 */

# include dependencies
include('buttonsnap.inc.php');
include('smilies-package.inc.php');

# Path constants.
define('k_SMILIES_PATH', dirname(__FILE__) .'/');
define('k_SMILIES_URL', get_settings('siteurl') .'/'. str_replace(ABSPATH, '', k_SMILIES_PATH));

# Version constant
define('k_SMILIES_VER', '2.1');


class more_smilies
{
	var $role = 'change_smilies';
	var $current_smilies = 'default';
	var $default_smilies = 'default';
	var $config_file = 'package-config.php';
	var $use_smilies = false;
	var $smilies;
	var $button_url;
	var $url;
	var $path;
	
	function more_smilies() {
		add_action('activate_'.$this->plugin_basename(__FILE__), array(&$this, 'activate'));
		add_action('deactivate_'.$this->plugin_basename(__FILE__), array(&$this, 'deactivate'));
		add_action('init', array(&$this, 'init'));
		add_action('admin_menu', array(&$this, 'button_init'));
		add_action('admin_menu', array(&$this, 'admin_menu'));
		add_action('comment_toolbar', array(&$this, 'clicker'));
		
		$this->default_smilies = get_option('more_smilies');
		$this->use_smilies = get_settings('use_smilies');
		$this->url = trailingslashit(k_SMILIES_URL);
		$this->path = k_SMILIES_PATH;
		$this->button_url = $this->url .'smile.png';
	}
	
	function init() {
		if (current_user_can($this->role))
			$this->current_smilies = get_user_option('more_smilies');
		else
			$this->current_smilies = $this->default_smilies;
		
		$this->smilies =& new smilies_package($this->current_smilies);
		
		# set our new smilies as the ones to use
		if ($this->use_smilies)
			$this->smilies->set_smilies();
	}
	
	
	/**
	 * Outputs a set of clickable smilies for use in WP's comment form. 
	 * Simply call the function do_action('comment_toolbar', 'comment');
	 * from within your template.
	 *
	 * @param string $textarea_name The name attribute of the comment textarea.
	 * @author Matt Read
	 * @author http://candy.zuavra.net/index.php/27/
	 */
	function clicker($textarea_name = 'comment') {
		#output clicker Javascript
		$this->clicker_js($textarea_name);
		
		# output unique smilies in reverse order (shortest to longest).
		foreach(array_unique(array_reverse($this->smilies->smilies)) as $smiley => $img) {
			echo '<a href="javascript:moreSmiliesAappendSmiley(\''.addslashes(trim($smiley)).'\')">';
			echo '<img src="'. $this->smilies->url_path .'/'. $img .'" alt="'. htmlspecialchars(trim($smiley), ENT_QUOTES) .'" class="wp-smiley" title="'. htmlspecialchars(trim($smiley), ENT_QUOTES) .'" />';
			echo '</a> ';
		}
	}
	
	function clicker_js($textarea_name) {
		ob_start();
		?>
		<script type="text/Javascript">
		<!--
			function moreSmiliesAappendSmiley(text) {
				var comment = document.getElementsByName('<?php echo $textarea_name; ?>')[0];
				comment.value = comment.value +' '+ text +' ';
				comment.focus();
			}
		-->
		</script>
		<?php
		ob_end_flush();
	}
	
	
	function replacer_js() {
		// empty
	}
	
	function check_all_js() {
		ob_start();
		?>
		<script type="text/javascript">
		<!--
		function checkAll(form)
		{
			for (i = 0, n = form.elements.length; i < n; i++) {
				if(form.elements[i].type == "checkbox") {
					if(form.elements[i].checked == false)
						form.elements[i].checked = true;
				}
			}
		}
		//-->
		</script>
		
		<input type="button" class="button" name="checkall" onclick="checkAll(document.forms[0]); return false;" value="<?php _e("Check All", 'more-smilies'); ?>" />
		<?php
		ob_end_flush();
	}
	
	
	function button_init() {
		# create the JS callback
		$js = "var template = '". $this->url ."popup.php'; window.open(template, 'smilies', 'top=200,left=200,scrollbars=yes,dialog=no,minimizable=yes,modal=yes,width=300,height=280,resizable=yes');";
		
		# register new button with buttonsnap.
		buttonsnap_jsbutton($this->button_url, 'Smilies', $js, 'any');
	}
	
	
	function activate() {
		add_option('more_smilies', 'default', 'The "More Smilies" package to use.', 'no');
		return true;
	}
	
	function deactivate() {
		global $wp_roles, $wpdb;
		
		$cur_roles = $wp_roles->get_names();
		foreach ($cur_roles as $role)
			$wp_roles->remove_cap($role, $this->role);
		
		$user_ids = $wpdb->get_results("SELECT ID FROM $wpdb->users");
		foreach($user_ids as $user_id)
			delete_usermeta($user_id, 'more_smilies');
		
		delete_option('more_smilies');
		return true;
	}
	
	function plugin_basename($file) {
		$file = preg_replace('/^.*wp-content[\\\\\/]plugins[\\\\\/]/', '', $file);
		return $file;
	}
	
	function load_textdomain() {
		$locale = get_locale();
		$domain = 'more-smilies';
		$mofile = ABSPATH . "wp-content/plugins/more-smilies/locale/$domain-$locale.mo";
		load_textdomain($domain, $mofile);
	}
	
	function admin_menu() {
		# add menu to profile if user can change smilies.
		add_submenu_page('profile.php', 'Smilies', 'Smilies', $this->role, $this->plugin_basename(__FILE__), array(&$this, 'personal_options_page'));
		
		add_options_page('More Smilies', 'More Smilies', 'manage_options', $this->plugin_basename(__FILE__), array(&$this, 'options_page'));
	}
	
	function get_package_list($path) {
		$packages = array();
		$packages_dir = @ dir($path);
		if ($packages_dir) {
			while(($package_dir = $packages_dir->read()) !== false) {
				if (is_dir($path . $package_dir)) {
					$this_package_dir = @ dir($path . $package_dir);
					while(($package_file = $this_package_dir->read()) !== false) {
						if ( $package_file == $this->config_file ) {
							$packages[] = $package_dir;
							break;
						}
					}
				}
			}
		}
		return $packages;
	}
	
	function update_options($personal = false) {
		global $current_user, $wp_roles;
		
		if ($_POST['action'] != 'update')
			return false;
		
		$value = trim(stripslashes($_POST['more_smilies']));
		if ($_POST['reset']) {
			delete_usermeta($current_user->ID, 'more_smilies');
			$this->current_smilies = $this->default_smilies;
			wp_cache_delete($this->current_smilies, 'smilies');
		}
		elseif ($personal) {
			update_user_option($current_user->ID, 'more_smilies', $value, true);
			$this->current_smilies = $value;
			wp_cache_delete($this->current_smilies, 'smilies');
		}
		else {
			update_option('more_smilies', $value);
			update_option('use_smilies', trim(stripslashes($_POST['use_smilies'])));
			# borrowed from RunPHP
			$role_perms = $_POST['can_change_smilies'];
			$role_names = $wp_roles->get_names();
			foreach ($role_names as $role => $role_name) {
				if (is_array($role_perms) && in_array($role, $role_perms)) {
					$tmp_role =& $wp_roles->get_role($role);
					$tmp_role->add_cap($this->role, true);
				}
				else {
					$tmp_role =& $wp_roles->get_role($role);
					$tmp_role->add_cap($this->role, false);
				}
			}
			$this->default_smilies = $value;
			$this->use_smilies = trim(stripslashes($_POST['use_smilies']));
			wp_cache_delete($this->default_smilies, 'smilies');
		}
		
		echo '<div id="message" class="updated fade"><p><strong>'. __('Options saved.', 'more-smilies') .'</strong></p></div>';
	}
	
	function options_page() {
		$this->load_textdomain();
		$this->update_options();
		
		if (!$this->use_smilies) {
			echo '<div id="message" class="updated fade-ff0000"><p><strong>'. __('You need to check "convert emoticons" for this to work.', 'more-smilies') .'</strong></p></div>';
		}
		$this->display_options_page();
	}
	
	function personal_options_page() {
		$this->load_textdomain();
		
		if (!current_user_can($this->role)) {
			print('<div class="wrap"><p>'. __('Sorry, You do not have permission to change smilies.', 'more-smilies') .'</p></div>');
			return;
		}
		if (!$this->use_smilies) {
			echo '<div id="message" class="updated fade-ff0000"><p><strong>'. __('Sorry, smilies have been disabled by the Administrator.', 'more-smilies') .'</strong></p></div>';
			return;
		}
		$this->update_options(true);
		$this->display_options_page(true);
	}
	
	function display_options_page($personal = false) {
		if ($personal)
			require('personal-options-page.inc.php');
		else
			require('options-page.inc.php');
	}
	
	function footer() {
		echo '<p style="text-align:center;margin-top:3em;">More Smilies '. k_SMILIES_VER .' by <a href="http://mattread.com" style="font-family:cursive; font-size:1.1em;">Matt Read</a>.</p>';
	}
}

$more_smilies = new more_smilies;

?>